| Title: | Perform Chromatin Segmentation Analysis in R by Calling ChromHMM |
|---|---|
| Description: | Chromatin segmentation analysis transforms ChIP-seq data into signals over the genome. The latter represents the observed states in a multivariate Markov model to predict the chromatin's underlying states. ChromHMM, written in Java, integrates histone modification datasets to learn the chromatin states de-novo. The goal of this package is to call chromHMM from within R, capture the output files in an S4 object and interface to other relevant Bioconductor analysis tools. In addition, segmenter provides functions to test, select and visualize the output of the segmentation. |
| Authors: | Mahmoud Ahmed [aut, cre] (ORCID: <https://orcid.org/0000-0002-4377-6541>) |
| Maintainer: | Mahmoud Ahmed <[email protected]> |
| License: | GPL-3 |
| Version: | 1.19.0 |
| Built: | 2026-04-30 17:33:51 UTC |
| Source: | https://github.com/bioc/segmenter |
BinarizeBed
Call the Java module BinarizeBed which binarize a bed file of the
aligned reads.
.Binarize(inputdir, cellmarkfiletable, chromsizefile, binsize, outputdir, type).Binarize(inputdir, cellmarkfiletable, chromsizefile, binsize, outputdir, type)
inputdir |
A string. The path to bed files. |
cellmarkfiletable |
A tab delimited files of three columns. The columns contains the cell, mark and the name or the bed file. |
chromsizefile |
A string. The path to the chromosomes sizes file. |
binsize |
An integer. The bin size to use. Default is 200. |
outputdir |
A string. The path to a directory where output will be written. |
type |
A string. The file type 'bam' or 'bed'. |
NULL. Output files are written to the output directory.
binarize_bed
LearnModel
Call the Java module LearnModel which learns a multi-state model
from ChIP-seq data.
.LearnModel( inputdir, outputdir, numstates, coordsdir, anchorsdir, chromsizefile, assembly, optional ).LearnModel( inputdir, outputdir, numstates, coordsdir, anchorsdir, chromsizefile, assembly, optional )
inputdir |
A string. The path to binarized files. |
outputdir |
A string. The path to a directory where output will be written. |
numstates |
An integer. The number of desired states in the model. |
coordsdir |
A string. The path to genomic coordiantes files. |
anchorsdir |
A string. The path to the genomic anchors files. |
chromsizefile |
A string. The path to the chromosomes sizes file. |
assembly |
A string. The name of the genomic assembely. |
optional |
A string. Other optional arguments passed to the Java command. |
NULL. Output files are written to the output directory.
learn_model
segmentation objectsThese functions can be used to access the contents of segmentation
objects as well as modifying them.
model(object) ## S4 method for signature 'segmentation' model(object) emission(object) ## S4 method for signature 'segmentation' emission(object) transition(object) ## S4 method for signature 'segmentation' transition(object) overlap(object, ...) ## S4 method for signature 'segmentation' overlap(object, cell) TSS(object, ...) ## S4 method for signature 'segmentation' TSS(object, cell) TES(object, ...) ## S4 method for signature 'segmentation' TES(object, cell) segment(object, ...) ## S4 method for signature 'segmentation' segment(object, cell) bins(object, ...) ## S4 method for signature 'segmentation' bins(object, cell) counts(object, ...) ## S4 method for signature 'segmentation' counts(object, cell) likelihood(object) ## S4 method for signature 'segmentation' likelihood(object) cells(object) ## S4 method for signature 'segmentation' cells(object) states(object) ## S4 method for signature 'segmentation' states(object) markers(object) ## S4 method for signature 'segmentation' markers(object)model(object) ## S4 method for signature 'segmentation' model(object) emission(object) ## S4 method for signature 'segmentation' emission(object) transition(object) ## S4 method for signature 'segmentation' transition(object) overlap(object, ...) ## S4 method for signature 'segmentation' overlap(object, cell) TSS(object, ...) ## S4 method for signature 'segmentation' TSS(object, cell) TES(object, ...) ## S4 method for signature 'segmentation' TES(object, cell) segment(object, ...) ## S4 method for signature 'segmentation' segment(object, cell) bins(object, ...) ## S4 method for signature 'segmentation' bins(object, cell) counts(object, ...) ## S4 method for signature 'segmentation' counts(object, cell) likelihood(object) ## S4 method for signature 'segmentation' likelihood(object) cells(object) ## S4 method for signature 'segmentation' cells(object) states(object) ## S4 method for signature 'segmentation' states(object) markers(object) ## S4 method for signature 'segmentation' markers(object)
object |
An object of class |
... |
Other argument passed to the accessors |
cell |
A string |
The data in the corresponding slot or a subset of it.
segmentation
model(test_obj) emission(test_obj) transition(test_obj) overlap(test_obj) overlap(test_obj, cell = 'K562') TSS(test_obj) TSS(test_obj, cell = 'K562') TES(test_obj) TES(test_obj, cell = 'K562') segment(test_obj) segment(test_obj, cell = 'K562') bins(test_obj) counts(test_obj) likelihood(test_obj) cells(test_obj) states(test_obj) markers(test_obj)model(test_obj) emission(test_obj) transition(test_obj) overlap(test_obj) overlap(test_obj, cell = 'K562') TSS(test_obj) TSS(test_obj, cell = 'K562') TES(test_obj) TES(test_obj, cell = 'K562') segment(test_obj) segment(test_obj, cell = 'K562') bins(test_obj) counts(test_obj) likelihood(test_obj) cells(test_obj) states(test_obj) markers(test_obj)
Annotate the GRanges objects of the segments using
annotatePeak (see for details)
annotate_segments(segments, ...)annotate_segments(segments, ...)
segments |
A |
... |
Other arguments passed to |
A GRanges object which is identical to the input in addition
to the annotations as metadata columns.
library(TxDb.Hsapiens.UCSC.hg18.knownGene) txdb <- TxDb.Hsapiens.UCSC.hg18.knownGene segs <- segment(test_obj) segs_annotated <- annotate_segments(segs, TxDb = txdb, verbose = FALSE)library(TxDb.Hsapiens.UCSC.hg18.knownGene) txdb <- TxDb.Hsapiens.UCSC.hg18.knownGene segs <- segment(test_obj) segs_annotated <- annotate_segments(segs, TxDb = txdb, verbose = FALSE)
Transform the aligned reads into a binary format.
binarize_bam( inputdir, cellmarkfiletable, chromsizefile, binsize = 200, outputdir )binarize_bam( inputdir, cellmarkfiletable, chromsizefile, binsize = 200, outputdir )
inputdir |
A string. The dirctory of the bam files. |
cellmarkfiletable |
A string. The path to the input files table. Only |
chromsizefile |
A string. The path to the chromosomes sizes file. |
binsize |
An integer. The number in bp used to generate binarized files. |
outputdir |
A string. The path to a directory where output will be written. |
NULL. Write files to the outputdir
Binarize binarize_bed
# locate input and output files inputdir <- system.file("extdata", package = "bamsignals") cellmarkfiletable <- system.file('extdata', 'cell_mark_table.tsv', package = 'segmenter') chromsizefile <- system.file('extdata/CHROMSIZES', 'hg18.txt', package = 'chromhmmData') outputdir <- tempdir() # run command binarize_bam(inputdir, chromsizefile = chromsizefile, cellmarkfiletable = cellmarkfiletable, outputdir = outputdir) # show output files list.files(outputdir, pattern = '*_binary.txt')# locate input and output files inputdir <- system.file("extdata", package = "bamsignals") cellmarkfiletable <- system.file('extdata', 'cell_mark_table.tsv', package = 'segmenter') chromsizefile <- system.file('extdata/CHROMSIZES', 'hg18.txt', package = 'chromhmmData') outputdir <- tempdir() # run command binarize_bam(inputdir, chromsizefile = chromsizefile, cellmarkfiletable = cellmarkfiletable, outputdir = outputdir) # show output files list.files(outputdir, pattern = '*_binary.txt')
Transform the aligned reads into a binary format.
binarize_bed( inputdir, cellmarkfiletable, chromsizefile, binsize = 200, outputdir )binarize_bed( inputdir, cellmarkfiletable, chromsizefile, binsize = 200, outputdir )
inputdir |
A string. The dirctory of the bam files. |
cellmarkfiletable |
A string. The path to the input files table. Only |
chromsizefile |
A string. The path to the chromosomes sizes file. |
binsize |
An integer. The number in bp used to generate binarized files. |
outputdir |
A string. The path to a directory where output will be written. |
NULL. Write files to the outputdir
Binarize binarize_bam
Compare two or more models
compare_models(objs, type = "emission", plot = FALSE, ...)compare_models(objs, type = "emission", plot = FALSE, ...)
objs |
A list of segmentation items |
type |
A string. What to compare. Default to 'emission' |
plot |
A logical. |
... |
Other arguments passed to plot |
A numeric vector or a plot with the same values.
compare_models(test_objs) compare_models(test_objs, type = 'likelihood')compare_models(test_objs) compare_models(test_objs, type = 'likelihood')
GRanges objects from bam filesCount reads in GRanges objects from bam files
count_reads_ranges(ranges, cellmarkfiletable, inputbamdir)count_reads_ranges(ranges, cellmarkfiletable, inputbamdir)
ranges |
A |
cellmarkfiletable |
A string. The path to the input files table. |
inputbamdir |
A |
A SummarizedExperiment object with ranges as its
rowRanges and the counts as the assay.
Make emissions file name
emissions_file(numstates)emissions_file(numstates)
numstates |
An integer |
A string
emissions_file(3)emissions_file(3)
Make enrichment file names
enrichment_files(numstates, cells, table = "RefSeq", annotation = "TSS")enrichment_files(numstates, cells, table = "RefSeq", annotation = "TSS")
numstates |
An integer |
cells |
A character vector |
table |
A string |
annotation |
A string |
A character vector
enrichment_files(3, 'K562')enrichment_files(3, 'K562')
Get the frequency of the segments in each cell type
get_frequency(segments, normalize = FALSE, tidy = FALSE, plot = FALSE, ...)get_frequency(segments, normalize = FALSE, tidy = FALSE, plot = FALSE, ...)
segments |
A |
normalize |
A logical. Whether the frequency should be normalized by the total number of segments |
tidy |
A logical. |
plot |
A logical. |
... |
Other arguments passed to barplot |
A data.frame when tidy is TRUE otherwise a matrix or a plot
get_frequency(segment(test_obj)) get_frequency(segment(test_obj), normalize = TRUE)get_frequency(segment(test_obj)) get_frequency(segment(test_obj), normalize = TRUE)
Get the width of the segments in each cell type
get_width(segments, average = FALSE)get_width(segments, average = FALSE)
segments |
A |
average |
A logical. Whether the width should be averaged across cells. |
A data.frame
get_width(segment(test_obj)) get_width(segment(test_obj), average = TRUE)get_width(segment(test_obj)) get_width(segment(test_obj), average = TRUE)
Integrate multiple ChIP-seq chromatin datasets of histone modifications, transcription factors or other DNA binding proteins to build a multi-state model of the combinatorial and spatial frequently occurring patterns. The function uses as an input binarized ChIP-seq data and the genome annotations on which the states will be discovered.
learn_model( inputdir, outputdir, numstates, coordsdir, anchorsdir, chromsizefile, assembly, cells, annotation, binsize, inputbamdir, cellmarkfiletable, read_only = FALSE, read_bins = FALSE, counts = FALSE )learn_model( inputdir, outputdir, numstates, coordsdir, anchorsdir, chromsizefile, assembly, cells, annotation, binsize, inputbamdir, cellmarkfiletable, read_only = FALSE, read_bins = FALSE, counts = FALSE )
inputdir |
A string. The path to binarized files. |
outputdir |
A string. The path to a directory where output will be written. |
numstates |
An integer. The number of desired states in the model. |
coordsdir |
A string. The path to genomic coordinates files. |
anchorsdir |
A string. The path to the genomic anchors files. |
chromsizefile |
A string. The path to the chromosomes sizes file. |
assembly |
A string. The name of the genomic assembely. |
cells |
A |
annotation |
A string. The name of the type of annotation as it occurs in the genomic annotation files. |
binsize |
An integer. The number in bp used to generate binarized files. |
inputbamdir |
A string. The path to the input bam files. Only used when
|
cellmarkfiletable |
A string. The path to the input files table. Only
used when |
read_only |
A logical. Default is |
read_bins |
A logical. Default is |
counts |
A logical. Default is |
By default, this functions runs the analysis commands, writes the
output to files and loads it into an object of class
segmentation. In addition, the binarized data and the reads
counts in the bins can be loaded. When read_only is TRUE.
The functions looks for previously generated files in the output
directory and load them without rerunning the commands.
An object of class segmentation (see for details)
and the files written to the output directory.
LearnModel
# locate input and output files inputdir <- system.file('extdata/SAMPLEDATA_HG18', package = 'segmenter') outputdir <- tempdir() coordsdir <- system.file('extdata/COORDS', package = 'chromhmmData') anchorsdir <- system.file('extdata/ANCHORFILES', package = 'chromhmmData') chromsizefile <- system.file('extdata/CHROMSIZES', 'hg18.txt', package = 'chromhmmData') # run command obj <- learn_model(inputdir = inputdir, outputdir = outputdir, coordsdir = coordsdir, anchorsdir = anchorsdir, chromsizefile = chromsizefile, numstates = 3, assembly = 'hg18', cells = c('K562', 'GM12878'), annotation = 'RefSeq', binsize = 200) # show the output obj# locate input and output files inputdir <- system.file('extdata/SAMPLEDATA_HG18', package = 'segmenter') outputdir <- tempdir() coordsdir <- system.file('extdata/COORDS', package = 'chromhmmData') anchorsdir <- system.file('extdata/ANCHORFILES', package = 'chromhmmData') chromsizefile <- system.file('extdata/CHROMSIZES', 'hg18.txt', package = 'chromhmmData') # run command obj <- learn_model(inputdir = inputdir, outputdir = outputdir, coordsdir = coordsdir, anchorsdir = anchorsdir, chromsizefile = chromsizefile, numstates = 3, assembly = 'hg18', cells = c('K562', 'GM12878'), annotation = 'RefSeq', binsize = 200) # show the output obj
Merge segments and bins objects
merge_segments_bins(segments, bins)merge_segments_bins(segments, bins)
segments |
A |
bins |
A |
A SummarizedExperiment object with the segment assignment
added to the metadata of the rowRanges.
segmentation objectsThese functions can be used to interact with segmentation objects for
purposes other than accessing or modifying their contents.
## S4 method for signature 'segmentation' show(object)## S4 method for signature 'segmentation' show(object)
object |
An object of class |
Prints a summary of the segmentation object contents.
segmentation
accessors
show(test_obj)show(test_obj)
Make model file name
model_file(numstates)model_file(numstates)
numstates |
An integer |
A string
model_file(3)model_file(3)
Make overlap file names
overlap_files(numstates, cells)overlap_files(numstates, cells)
numstates |
An integer |
cells |
A character vector |
A character vector
overlap_files(3, 'K562')overlap_files(3, 'K562')
Visualize the model output
plot_heatmap(obj, type = "emission", ...)plot_heatmap(obj, type = "emission", ...)
obj |
A segmentation object |
type |
A string. Which kind of parameter to print. Default is 'emission' and possible values are 'emission', 'transition', 'overlap', 'TSS' or 'TES' |
... |
Other arguments to path to Heatmap |
A heatmap
plot_heatmap(test_obj)plot_heatmap(test_obj)
The function takes the data.frames of the loaded binarized data files
and format them into GRanges or SummarizedExperiment objects.
range_bins(bins, chromsizefile, binsize, return = "GRanges", tidy = TRUE)range_bins(bins, chromsizefile, binsize, return = "GRanges", tidy = TRUE)
bins |
A |
chromsizefile |
A string. The path to the chromosomes sizes file. |
binsize |
An integer. The number in bp used to generate binarized files. |
return |
A string. Possible values are |
tidy |
A |
GRanges (default) or SummarizedExperiment.
The function takes the data.frames of the loaded counts data and
format them into GRanges or SummarizedExperiment objects.
range_counts( counts, features, return = "GRanges", tidy = FALSE, average = FALSE, marks )range_counts( counts, features, return = "GRanges", tidy = FALSE, average = FALSE, marks )
counts |
A |
features |
A |
return |
A string. Possible values are |
tidy |
A |
average |
A |
marks |
A |
GRanges (default) or SummarizedExperiment.
bam filesCount the reads in each range of the GRanges object
read_bam_file(file, features, ...)read_bam_file(file, features, ...)
file |
A string. The path to the file. |
features |
A |
... |
Other arguments passed to |
A matrix
# locate the bam file bam_file <- system.file("extdata", "randomBam.bam", package = "bamsignals") # load a granges object rand_anno <- system.file("extdata", "randomAnnot.Rdata", package = "bamsignals") features <- GenomicRanges::promoters(get(load(rand_anno))) # count reads in ranges read_bam_file(bam_file, features)# locate the bam file bam_file <- system.file("extdata", "randomBam.bam", package = "bamsignals") # load a granges object rand_anno <- system.file("extdata", "randomAnnot.Rdata", package = "bamsignals") features <- GenomicRanges::promoters(get(load(rand_anno))) # count reads in ranges read_bam_file(bam_file, features)
bins filesThe files contain the cell and the chromosome info in the first line and the binarized data from all marks in the rest.
read_bins_file(file)read_bins_file(file)
file |
A string. The path to the file. |
A list of 3 items: cell, seqname and binaries.
# locate the file fl <- system.file('extdata/SAMPLEDATA_HG18/', 'GM12878_chr11_binary.txt.gz', package = 'segmenter') # read the file read_bins_file(fl)# locate the file fl <- system.file('extdata/SAMPLEDATA_HG18/', 'GM12878_chr11_binary.txt.gz', package = 'segmenter') # read the file read_bins_file(fl)
cellmarktable fileThe file should contain at least three columns: cell, mark and file for the names of the cells/conditions, the available marks and binarized data files.
read_cellmark_file(file)read_cellmark_file(file)
file |
A string. The path to the file. |
A data.frame
# locate the file fl <- system.file('extdata', 'cell_mark_table.tsv', package = 'segmenter') # read the file read_cellmark_file(fl)# locate the file fl <- system.file('extdata', 'cell_mark_table.tsv', package = 'segmenter') # read the file read_cellmark_file(fl)
chromsizefile
The file should contain exactly two columns. One for the name of the chromosome and the other for its length.
read_chromsize_file(file)read_chromsize_file(file)
file |
A string. The path to the file. |
A data.frame
# locate the file chromsizefile <- system.file('extdata/CHROMSIZES', 'hg18.txt', package = 'chromhmmData') # read the file read_chromsize_file(chromsizefile)# locate the file chromsizefile <- system.file('extdata/CHROMSIZES', 'hg18.txt', package = 'chromhmmData') # read the file read_chromsize_file(chromsizefile)
emissions fileThe segments files are the output of running learn_model and named
emissions_3_segment.bed
read_emissions_file(file, states, marks)read_emissions_file(file, states, marks)
file |
A string. The path to the file. |
states |
A |
marks |
A |
A matrix
# locate the file fl <- file.path(tempdir(), 'emissions_3.txt') # read the file read_emissions_file(fl)# locate the file fl <- file.path(tempdir(), 'emissions_3.txt') # read the file read_emissions_file(fl)
enrichment filesThe segments files are the output of running learn_model and named
<cell>_3_TSS.txt or <cell>_3_TES.txt.
read_enrichment_file(file, states, regions)read_enrichment_file(file, states, regions)
file |
A string. The path to the file. |
states |
A |
regions |
A |
A matrix
# locate the file fl <- file.path(tempdir(), 'GM12878_3_RefSeqTSS_neighborhood.txt') # read the file read_enrichment_file(fl)# locate the file fl <- file.path(tempdir(), 'GM12878_3_RefSeqTSS_neighborhood.txt') # read the file read_enrichment_file(fl)
modelfile
The model file is the output of running learn_model and named
model_#.txt
read_model_file(file)read_model_file(file)
file |
A string. The path to the file. |
A data.frame
# locate the file modelfile <- file.path(tempdir(), 'model_3.txt') # read the file read_model_file(modelfile)# locate the file modelfile <- file.path(tempdir(), 'model_3.txt') # read the file read_model_file(modelfile)
segments filesThe segments files are the output of running learn_model and named
<cell>_3_overlap.txt
read_overlap_file(file, states, regions)read_overlap_file(file, states, regions)
file |
A string. The path to the file. |
states |
A |
regions |
A |
A matrix
# locate the file fl <- file.path(tempdir(), 'GM12878_3_overlap.txt') # read the file read_overlap_file(fl)# locate the file fl <- file.path(tempdir(), 'GM12878_3_overlap.txt') # read the file read_overlap_file(fl)
segments filesThe segments files are the output of running learn_model and named
<cell>_3_segment.bed
read_segements_file(file, states)read_segements_file(file, states)
file |
A string. The path to the file. |
states |
A |
A data.frame
# locate the file segmentfile <- file.path(tempdir(), 'GM12878_3_segments.bed') # read the file segs <- read_segements_file(segmentfile) head(segs)# locate the file segmentfile <- file.path(tempdir(), 'GM12878_3_segments.bed') # read the file segs <- read_segements_file(segmentfile) head(segs)
transitions fileThe segments files are the output of running learn_model and named
transitions_3_segment.bed
read_transitions_file(file, states)read_transitions_file(file, states)
file |
A string. The path to the file. |
states |
A |
A matrix
# locate the file fl <- file.path(tempdir(), 'transitions_3.txt') # read the file read_transitions_file(fl)# locate the file fl <- file.path(tempdir(), 'transitions_3.txt') # read the file read_transitions_file(fl)
The segmentation class consists of matrices and lists. The components
contain the output of the chromatin segmentation analysis. Loading the input
data is optional. The object is returned as a result of calling
learn_model or reading its already existing output.
modellist. The list consists of 6 items corresponding
to the contents of the model_#.txt file. These are
number_states and number_marks for the numbers of states
and marks in the model; likelihood and probinit for the
likelihood and the initial probabilities of the multi-state model;
transitionprobs and emissionprobs for the probabilities
of the transitions and emissions parameters of the model. Can be
accessed using model.
emissionmatrix. The matrix contains the emission
parameters of n states (rows) for n marks (columns) corresponding to
the contents of the emission_#.txt file. Can be accessed using
emission.
transitionmatrix. The matrix contains the transition
parameters of n by n states corresponding to the contents of the
transition_#.txt file. Can be accessed using
transition.
overlaplist. A list of n number of cells/conditions items.
Each item is a matrix of the overlap enrichment of n states
(rows) at n genomic annotations (columns) corresponding to the contents
of the <cell>_#_overlap.txt files. Can be accessed using
overlap.
TSSlist. A list of n number of cells/conditions items.
Each item is a matrix of the overlap enrichment of n states
(rows) at n locations around the transcription start site (TSS)
(columns) corresponding to the contents of the
<cell>_#_TSS_neighborhood.txt files. Can be accessed using
TSS.
TESlist. A list of n number of cells/conditions items.
Each item is a matrix of the overlap enrichment of n states
(rows) at n locations around the transcription end site (TES)
(columns) corresponding to the contents of the
<cell>_#_TES_neighborhood.txt files. Can be accessed using
TES.
segmentlist. A list of n number of cells/conditions items.
Each item is a GRanges object containing the
segmentation and assigned states as a metadata column 'state'. These
contents correspond to the <cell>_#_segment.bed files. Annotations
of the ranges are optional. Can be accessed using segment.
binslist. A list of n number of cells/conditions items.
Each item is a SummarizedExperiment
object containing the binarized input data. The coordinates of the bins
are saved as the rowRanges each
assigned to a state and the binary data itself is saved as
assay. Can be accessed using
bins.
countslist. A list of n number of cells/conditions items.
Each item is a SummarizedExperiment
object containing the read counts in bins. The coordinates of the bins
are saved as the rowRanges each
assigned to a state and the counts data itself is saved as
assay. Can be accessed using
counts.
Make segments file names
segments_files(numstates, cells)segments_files(numstates, cells)
numstates |
An integer |
cells |
A character vector |
A character vector
segments_files(3, 'K562')segments_files(3, 'K562')
A segmentation object generated by running lean_model on the test
dataset in 'inst/extdata/ChromHMM/SAMPLEDATA_HG18'. The source code to
this run is in 'inst/script/test_obj.R'
test_objtest_obj
An object of class segmentation of length 1.
A segmentation object generated by running lean_model on the test
dataset in 'inst/extdata/ChromHMM/SAMPLEDATA_HG18' for 3 to 8 states.
The source code to this run is in 'inst/script/test_objs.R'
test_objstest_objs
An object of class list of length 6.
GRanges objectTidy the metadata of a GRanges object
tidy_ranges(gr, columns, low = 0)tidy_ranges(gr, columns, low = 0)
gr |
A |
columns |
A |
low |
An |
A GRanges object
tidy_ranges(segment(test_obj, cell = 'K562')[[1]])tidy_ranges(segment(test_obj, cell = 'K562')[[1]])
Make transitions file name
transitions_file(numstates)transitions_file(numstates)
numstates |
An integer |
A string
transitions_file(3)transitions_file(3)